@@ -20,7 +20,9 @@ def sql(key):
         'KpiTemplateID': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
         'KpiTemplateID1': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
         'KpiTemplateID2': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
-        'LogwareHouse': {'sql': "SELECT id From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
+        'logWareHouseID': {'sql': "SELECT id From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
+        'logWareHouseId': {'sql': "SELECT id From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
+        'wareHouseName': {'sql': "SELECT wareHouseName From LogWareHouse;", 'database': 'AnyRobot'},
         'dataType': {'sql': "SELECT dataType From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
         'indexID': {'sql': "SELECT id From IndexParams;", 'database': 'AnyRobot'},
         'indexName': {'sql': "SELECT indexName From IndexParams;", 'database': 'AnyRobot'},
@@ -28,8 +30,10 @@ def sql(key):
         'LogGroupIdPare': {'sql': 'SELECT groupId From LogGroup where GroupName="所有日志";', 'database': 'AnyRobot'},
         'RoleId': {'sql': 'SELECT roleId From Role where roleName ="admin";', 'database': 'AnyRobot'},
         'tagGroupID': {'sql': "SELECT id From TagGroup;", 'database': 'AnyRobot'},
-        'tagID': {'sql': "SELECT id From Tag;", 'database': 'AnyRobot'}
-
+        'tagID': {'sql': "SELECT id From Tag;", 'database': 'AnyRobot'},
+        'HostID': {'sql': "SELECT ip From AgentHost;", 'database': 'AnyRobot'},
+        'openapiID': {'sql': "SELECT id From OpenAPIManager;", 'database': 'AnyRobotOpenLog'},
+        'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin";', 'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
